.. _modeling:

====================================
Data Modeling (`skhep.modeling`)
====================================

.. automodule:: skhep.modeling
   :members:

.. automodule:: skhep.modeling.bayesian_blocks
    :members:
